/******************************************************************************
 * hiperiso_qt.h
 *
 * Copyright (c) 2021, longpanda <admin@hiperiso.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef __HIPERISO_QT_H__
#define __HIPERISO_QT_H__

int hiperiso_disk_init(void);
void hiperiso_disk_exit(void);
int hiperiso_http_init(void);
void hiperiso_http_exit(void);
int hiperiso_log_init(void);
void hiperiso_log_exit(void);
void *get_refresh_icon_raw_data(int *len);
void *get_secure_icon_raw_data(int *len);
void *get_window_icon_raw_data(int *len);
int hiperiso_func_handler(const char *jsonstr, char *jsonbuf, int buflen);
const char * hiperiso_code_get_cur_language(void);
int hiperiso_code_get_cur_part_style(void);
void hiperiso_code_set_cur_part_style(int style);
int hiperiso_code_get_cur_show_all(void);
void hiperiso_code_set_cur_show_all(int show_all);
void hiperiso_code_set_cur_language(const char *lang);
void hiperiso_code_save_cfg(void);
void hiperiso_code_refresh_device(void);
int hiperiso_code_is_busy(void);
int hiperiso_code_get_percent(void);
int hiperiso_code_get_result(void);

#endif /* __HIPERISO_QT_H__ */


